# RentcastPropertyRecords200ResponseInnerTaxAssessments


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**var_2020** | [**RentcastPropertyRecords200ResponseInnerTaxAssessments2020**](RentcastPropertyRecords200ResponseInnerTaxAssessments2020.md) |  | [optional] 
**var_2021** | [**RentcastPropertyRecords200ResponseInnerTaxAssessments2021**](RentcastPropertyRecords200ResponseInnerTaxAssessments2021.md) |  | [optional] 
**var_2022** | [**RentcastPropertyRecords200ResponseInnerTaxAssessments2022**](RentcastPropertyRecords200ResponseInnerTaxAssessments2022.md) |  | [optional] 
**var_2023** | [**RentcastPropertyRecords200ResponseInnerTaxAssessments2023**](RentcastPropertyRecords200ResponseInnerTaxAssessments2023.md) |  | [optional] 
**var_2024** | [**RentcastPropertyRecords200ResponseInnerTaxAssessments2024**](RentcastPropertyRecords200ResponseInnerTaxAssessments2024.md) |  | [optional] 

## Example

```python
from rentcast_client.models.rentcast_property_records200_response_inner_tax_assessments import RentcastPropertyRecords200ResponseInnerTaxAssessments

# TODO update the JSON string below
json = "{}"
# create an instance of RentcastPropertyRecords200ResponseInnerTaxAssessments from a JSON string
rentcast_property_records200_response_inner_tax_assessments_instance = RentcastPropertyRecords200ResponseInnerTaxAssessments.from_json(json)
# print the JSON string representation of the object
print(RentcastPropertyRecords200ResponseInnerTaxAssessments.to_json())

# convert the object into a dict
rentcast_property_records200_response_inner_tax_assessments_dict = rentcast_property_records200_response_inner_tax_assessments_instance.to_dict()
# create an instance of RentcastPropertyRecords200ResponseInnerTaxAssessments from a dict
rentcast_property_records200_response_inner_tax_assessments_from_dict = RentcastPropertyRecords200ResponseInnerTaxAssessments.from_dict(rentcast_property_records200_response_inner_tax_assessments_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


